Source-Changes-HG archive

[Date Prev][Date Next][Thread Prev][Thread Next][Date Index][Thread Index][Old Index]

[src/trunk]: src/sys/dev/ic Number of luns supported for SCC-2 is actually re...



details:   https://anonhg.NetBSD.org/src/rev/6f9b31240898
branches:  trunk
changeset: 525900:6f9b31240898
user:      mjacob <mjacob%NetBSD.org@localhost>
date:      Sat Apr 20 05:05:56 2002 +0000

description:
Number of luns supported for SCC-2 is actually really 16384- top
3 bits are lun address modifiers.

Remove code that (incorrectly) thought it was asking the f/w to only
PLOGI if not already PLOGI'd. The current f/w documentation tells us
that we have this backwards.

diffstat:

 sys/dev/ic/isp.c |  12 ++++--------
 1 files changed, 4 insertions(+), 8 deletions(-)

diffs (47 lines):

diff -r 76d155dd201b -r 6f9b31240898 sys/dev/ic/isp.c
--- a/sys/dev/ic/isp.c  Sat Apr 20 05:01:58 2002 +0000
+++ b/sys/dev/ic/isp.c  Sat Apr 20 05:05:56 2002 +0000
@@ -1,4 +1,4 @@
-/* $NetBSD: isp.c,v 1.92 2002/04/11 02:32:03 mjacob Exp $ */
+/* $NetBSD: isp.c,v 1.93 2002/04/20 05:05:56 mjacob Exp $ */
 /*
  * This driver, which is contained in NetBSD in the files:
  *
@@ -68,7 +68,7 @@
  */
 
 #include <sys/cdefs.h>
-__KERNEL_RCSID(0, "$NetBSD: isp.c,v 1.92 2002/04/11 02:32:03 mjacob Exp $");
+__KERNEL_RCSID(0, "$NetBSD: isp.c,v 1.93 2002/04/20 05:05:56 mjacob Exp $");
 
 #ifdef __NetBSD__
 #include <dev/ic/isp_netbsd.h>
@@ -804,7 +804,7 @@
         * of knowing how many luns we support.
         *
         * Expanded lun firmware gives you 32 luns for SCSI cards and
         * 65536 luns for Fibre Channel cards.
         *
         * It turns out that even for QLogic 2100s with ROM 1.10 and above
         * we do get a firmware attributes word returned in mailbox register 6.
@@ -827,7 +827,7 @@
                        }
                } else {
                        if (FCPARAM(isp)->isp_fwattr & ISP_FW_ATTR_SCCLUN) {
-                               isp->isp_maxluns = 65536;
+                               isp->isp_maxluns = 16384;
                        } else {
                                isp->isp_maxluns = 16;
                        }
@@ -1923,10 +1923,6 @@
                        mbs.param[1] = loopid << 8;
                        mbs.param[2] = portid >> 16;
                        mbs.param[3] = portid & 0xffff;
-                       if (IS_2200(isp) || IS_23XX(isp)) {
-                               /* only issue a PLOGI if not logged in */
-                               mbs.param[1] |= 0x1;
-                       }
                        isp_mboxcmd(isp, &mbs, MBLOGALL & ~(MBOX_LOOP_ID_USED |
                            MBOX_PORT_ID_USED | MBOX_COMMAND_ERROR));
                        if (fcp->isp_fwstate != FW_READY ||
@@ -804,7 +804,7 @@
         *
         * Expanded lun firmware gives you 32 luns for SCSI cards and
-        * 65536 luns for Fibre Channel cards.
+        * 16384 luns for Fibre Channel cards.
         *
         * It turns out that even for QLogic 2100s with ROM 1.10 and above



Home | Main Index | Thread Index | Old Index